##  Overview
Fact sheet fields are individual data points or elements within a fact sheet that provide specific information about the item or subject. You can modify predefined fields as well as add custom ones to adjust the fact sheet configuration to your needs.
Fields are the key element for collecting, managing, and analyzing data. You can adjust the visibility of fields on fact sheets, in inventory filters, and in report and diagram views. By efficiently configuring fields, you can enhance data quality, enrichment, and usability.
